@@ -7,9 +7,9 @@
 ;; Keywords: convenience, completion
 ;; Package-Requires: ((emacs "25.1") (async "1.9.1"))
 ;; URL: https://savannah.nongnu.org/projects/paced-el/
-;; Version: 1.0
+;; Version: 1.1
 ;; Created: 22 Jan 2017
-;; Modified: 08 Dec 2017
+;; Modified: 04 Feb 2018
 
 ;; This file is part of GNU Emacs.
 
@@ -89,11 +89,11 @@
 (ert-deftest paced-enable-list-symbol ()
   "Test case for `paced-dictionary-enable-alist' being an arbitrary symbol."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((paced-test-enable-symbol . "test-dict-case")))
-         (new-buffer (find-file-noselect paced-first-test-file))
-         (new-dict (paced-make-dictionary "test-dict-case"
-                                          paced-test-dict-save-file
-                                          'downcase)))
+         (paced-global-dictionary-enable-alist '((paced-test-enable-symbol . "test-dict-case")))
+         (new-buffer (find-file-noselect paced-first-test-file)))
+    (paced-make-dictionary "test-dict-case"
+                           paced-test-dict-save-file
+                           'downcase)
     (with-current-buffer new-buffer
       (setq paced-test-enable-symbol nil)
       (should-not (paced-current-dictionary))
@@ -105,12 +105,12 @@
 (ert-deftest paced-enable-list-mode ()
   "Test case for `paced-dictionary-enable-alist' being a mode symbol."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (buffer-one (find-file-noselect paced-first-test-file))
-         (buffer-two (find-file-noselect paced-second-test-file))
-         (new-dict (paced-make-dictionary "test-dict-case"
-                                          paced-test-dict-save-file
-                                          'downcase)))
+         (buffer-two (find-file-noselect paced-second-test-file)))
+    (paced-make-dictionary "test-dict-case"
+                           paced-test-dict-save-file
+                           'downcase)
     (with-current-buffer buffer-two
       (should-not (paced-current-dictionary)))
     (kill-buffer buffer-two)
@@ -125,11 +125,11 @@
 (ert-deftest paced-enable-list-function-symbol ()
   "Test case for `paced-dictionary-enable-alist' being a function symbol."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((paced-test-function-symbol . "test-dict-case")))
-         (buffer-one (find-file-noselect paced-first-test-file))
-         (new-dict (paced-make-dictionary "test-dict-case"
-                                          paced-test-dict-save-file
-                                          'downcase)))
+         (paced-global-dictionary-enable-alist '((paced-test-function-symbol . "test-dict-case")))
+         (buffer-one (find-file-noselect paced-first-test-file)))
+    (paced-make-dictionary "test-dict-case"
+                           paced-test-dict-save-file
+                           'downcase)
     (with-current-buffer buffer-one
       (setq-local paced-test-enable-symbol nil)
       (should-not (paced-current-dictionary))
@@ -141,11 +141,11 @@
 (ert-deftest paced-enable-list-lambda-function ()
   "Test case for `paced-dictionary-enable-alist' being a lambda form."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '(((lambda nil paced-test-enable-symbol) . "test-dict-case")))
-         (buffer-one (find-file-noselect paced-first-test-file))
-         (new-dict (paced-make-dictionary "test-dict-case"
-                                          paced-test-dict-save-file
-                                          'downcase)))
+         (paced-global-dictionary-enable-alist '(((lambda nil paced-test-enable-symbol) . "test-dict-case")))
+         (buffer-one (find-file-noselect paced-first-test-file)))
+    (paced-make-dictionary "test-dict-case"
+                           paced-test-dict-save-file
+                           'downcase)
     (with-current-buffer buffer-one
       (setq-local paced-test-enable-symbol nil)
       (should-not (paced-current-dictionary))
@@ -157,12 +157,12 @@
 (ert-deftest paced-enable-list-and-form ()
   "Test case for `paced-dictionary-enable-alist' being an 'and' form."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '(((and text-mode paced-test-enable-symbol) . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '(((and text-mode paced-test-enable-symbol) . "test-dict-case")))
          (buffer-one (find-file-noselect paced-first-test-file))
-         (buffer-two (find-file-noselect paced-second-test-file))
-         (new-dict (paced-make-dictionary "test-dict-case"
-                                          paced-test-dict-save-file
-                                          'downcase)))
+         (buffer-two (find-file-noselect paced-second-test-file)))
+    (paced-make-dictionary "test-dict-case"
+                           paced-test-dict-save-file
+                           'downcase)
     (with-current-buffer buffer-two
       (setq-local paced-test-enable-symbol nil)
       (should-not (paced-current-dictionary))
@@ -180,12 +180,12 @@
 (ert-deftest paced-enable-list-or-form ()
   "Test case for `paced-dictionary-enable-alist' being an 'or' form."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '(((or text-mode paced-test-enable-symbol) . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '(((or text-mode paced-test-enable-symbol) . "test-dict-case")))
          (buffer-one (find-file-noselect paced-first-test-file))
-         (buffer-two (find-file-noselect paced-second-test-file))
-         (new-dict (paced-make-dictionary "test-dict-case"
-                                          paced-test-dict-save-file
-                                          'downcase)))
+         (buffer-two (find-file-noselect paced-second-test-file)))
+    (paced-make-dictionary "test-dict-case"
+                           paced-test-dict-save-file
+                           'downcase)
     (with-current-buffer buffer-two
       (setq-local paced-test-enable-symbol nil)
       (should-not (paced-current-dictionary))
@@ -205,7 +205,7 @@
 (ert-deftest paced-populate-file ()
   "Test case for single file populator."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (cmd (paced-file-population-command :file paced-first-test-file))
          (test-dict (paced-make-dictionary "test-dict-case"
                                            paced-test-dict-save-file
@@ -224,7 +224,7 @@
 (ert-deftest paced-populate-buffer ()
   "Test case for single buffer populator."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (buffer "first.txt")
          (buffer-one (find-file-noselect paced-first-test-file))
          (cmd (paced-buffer-population-command :buffer buffer))
@@ -246,7 +246,7 @@
 (ert-deftest paced-populate-file-function ()
   "Test case for file-function populator."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (pre-func (lambda () (insert (buffer-string)) t))
          (cmd (paced-file-function-population-command :file paced-first-test-file
                                                       :setup-func pre-func))
@@ -267,7 +267,7 @@
 (ert-deftest paced-populate-directory-regexp ()
   "Test case for directory-regexp populator."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (cmd (paced-directory-regexp-population-command :directory paced-test-dir
                                                          :regexp ".*\\.txt"
                                                          :recursive t))
@@ -288,12 +288,12 @@
 (ert-deftest paced-populate-file-list ()
   "Test case for file-list populator."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (file-list (lambda () `(,paced-first-test-file)))
          (cmd (paced-file-list-population-command :generator file-list))
          (test-dict (paced-make-dictionary "test-dict-case"
-                                           paced-test-dict-save-file
-                                           'downcase)))
+                           paced-test-dict-save-file
+                           'downcase)))
     (should (paced-dictionary-p test-dict))
     (oset test-dict population-commands (list cmd))
     (paced-dictionary-repopulate test-dict)
@@ -307,7 +307,7 @@
 
 (ert-deftest paced-multiple-population-commands ()
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (cmd1 (paced-file-population-command :file paced-first-test-file))
          (cmd2 (paced-file-population-command :file paced-third-test-file))
          (test-dict (paced-make-dictionary "test-dict-case"
@@ -329,7 +329,7 @@
 
 (ert-deftest paced-populator-settings ()
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (exclude-command (lambda nil (nth 8 (syntax-ppss)))) ;; exclude comments
          (cmd1 (paced-file-population-command :file paced-first-test-file))
          (cmd2 (paced-file-population-command :file paced-second-test-file
@@ -351,7 +351,7 @@
 (ert-deftest paced-populate-sort-order ()
   "Test case for sorting after population."
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (cmd (paced-file-population-command :file paced-first-test-file))
          (test-dict (paced-make-dictionary "test-dict-case"
                                            paced-test-dict-save-file
@@ -395,7 +395,7 @@
 
 (ert-deftest paced-completions-try-completion ()
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (cmd (paced-file-population-command :file paced-first-test-file))
          (test-dict (paced-make-dictionary "test-dict-case"
                                            paced-test-dict-save-file
@@ -408,7 +408,7 @@
 
 (ert-deftest paced-completions-try-completion-mixed-case ()
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (cmd (paced-file-population-command :file paced-first-test-file))
          (test-dict (paced-make-dictionary "test-dict-case"
                                            paced-test-dict-save-file
@@ -421,7 +421,7 @@
 
 (ert-deftest paced-completions-all-completions ()
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (cmd (paced-file-population-command :file paced-first-test-file))
          (test-dict (paced-make-dictionary "test-dict-case"
                                            paced-test-dict-save-file
@@ -440,7 +440,7 @@
 
 (ert-deftest paced-completions-test-completion ()
   (let* ((paced--registered-dictionaries paced-test-default-registered-map)
-         (paced-global-dict-enable-alist '((text-mode . "test-dict-case")))
+         (paced-global-dictionary-enable-alist '((text-mode . "test-dict-case")))
          (cmd (paced-file-population-command :file paced-first-test-file))
          (test-dict (paced-make-dictionary "test-dict-case"
                                            paced-test-dict-save-file
@@ -463,6 +463,34 @@
     (should (equal (map-elt merged-2 'a) '("def")))
     (should (equal (map-elt merged-2 'c) '("ghi")))))
 
+(ert-deftest paced-beginning-end-of-thing-at-point ()
+  "Test exclusion and `paced-point-in-thing-at-point-for-exclusion'."
+  (let* ((paced-exclude-function (lambda () (looking-at-p "one")))
+         (buffer-one (find-file-noselect paced-first-test-file)))
+    (with-current-buffer buffer-one
+      (goto-char (point-min))
+      (should (equal (paced-thing-at-point) "one"))
+      (let ((paced-point-in-thing-at-point-for-exclusion 'beginning))
+        (should (paced-excluded-p)))
+      (paced-forward-thing)
+      (should (equal (paced-thing-at-point) "one"))
+      (let ((paced-point-in-thing-at-point-for-exclusion 'end))
+        (should-not (paced-excluded-p))))))
+
+(ert-deftest paced-character-limit ()
+  "Test character limit."
+  (let* ((paced-exclude-function (lambda () nil))
+         (buffer-one (find-file-noselect paced-first-test-file)))
+    (with-current-buffer buffer-one
+      (goto-char (point-min))
+      (should (equal (paced-thing-at-point) "one"))
+      (let* ((paced-character-limit 0))
+        (should-not (paced-excluded-p)))
+      (let* ((paced-character-limit 1))
+        (should (paced-excluded-p)))
+      (let* ((paced-character-limit 3))
+        (should-not (paced-excluded-p))))))
+
 (provide 'paced-tests)
 
 ;;; paced-tests.el ends here
